@@ -32,7 +32,7 @@ fn eval_and_unwrap(ctxt: &mut CommandContext, code: &str) -> HashMap<String, Str
                         println!("{}", error.rendered());
                     }
                 }
-                other => println!("{}", other),
+                other => println!("{other}"),
             }
 
             panic!("Unexpected compilation error. See above for details");
@@ -56,7 +56,7 @@ fn send_output<T: io::Write + Send + 'static>(
 ) {
     std::thread::spawn(move || {
         while let Ok(line) = channel.recv() {
-            if writeln!(output, "{}", line).is_err() {
+            if writeln!(output, "{line}").is_err() {
                 break;
             }
         }
@@ -163,7 +163,7 @@ fn save_and_restore_variables() {
     match e.execute("b = 2;") {
         Err(Error::CompilationErrors(errors)) => {
             if errors.len() != 1 {
-                println!("{:#?}", errors);
+                println!("{errors:#?}");
             }
             assert_eq!(errors.len(), 1);
             if errors[0].code() != Some("E0594") && errors[0].code() != Some("E0384") {
@@ -208,7 +208,7 @@ fn missing_semicolon_on_let_stmt() {
             assert!(e.first().unwrap().message().contains(';'));
         }
         x => {
-            panic!("Unexpected result: {:?}", x);
+            panic!("Unexpected result: {x:?}");
         }
     }
 }
@@ -217,16 +217,21 @@ fn missing_semicolon_on_let_stmt() {
 fn printing() {
     let (mut e, outputs) = new_command_context_and_outputs();
 
-    eval!(e,
-        println!("This is stdout");
-        eprintln!("This is stderr");
-        println!("Another stdout line");
-        eprintln!("Another stderr line");
-    );
+    let handle = std::thread::spawn(move || {
+        eval!(e,
+            println!("This is stdout");
+            eprintln!("This is stderr");
+            println!("Another stdout line");
+            eprintln!("Another stderr line");
+        );
+    });
+
     assert_eq!(outputs.stdout.recv(), Ok("This is stdout".to_owned()));
     assert_eq!(outputs.stderr.recv(), Ok("This is stderr".to_owned()));
     assert_eq!(outputs.stdout.recv(), Ok("Another stdout line".to_owned()));
     assert_eq!(outputs.stderr.recv(), Ok("Another stderr line".to_owned()));
+
+    handle.join().unwrap();
 }
 
 #[test]
@@ -310,7 +315,7 @@ fn function_panics_without_variable_preserving() {
     if let Err(Error::SubprocessTerminated(message)) = result {
         assert!(message.contains("Subprocess terminated"));
     } else {
-        panic!("Unexpected result: {:?}", result);
+        panic!("Unexpected result: {result:?}");
     }
     assert_eq!(variable_names_and_types(&e), vec![]);
     // Make sure that a compilation error doesn't bring the variables back from
@@ -371,11 +376,10 @@ impl TmpCrate {
             format!(
                 "\
                  [package]\n\
-                 name = \"{}\"\n\
+                 name = \"{name}\"\n\
                  version = \"0.0.1\"\n\
                  edition = \"2018\"\n\
-                 ",
-                name
+                 "
             ),
         )?;
         std::fs::write(src_dir.join("lib.rs"), src)?;
@@ -390,7 +394,7 @@ impl TmpCrate {
         let path = self.tempdir.path().to_string_lossy().replace('\\', "\\\\");
         self.path = Some(path.clone());
         if extra_options.is_empty() {
-            format!(":dep {}", path)
+            format!(":dep {path}")
         } else {
             format!(
                 ":dep {} = {{ path = \"{}\", {} }}",
@@ -404,6 +408,7 @@ impl TmpCrate {
     }
 }
 
+#[cfg(not(windows))]
 #[test]
 fn crate_deps() {
     let (mut e, _) = new_command_context_and_outputs();
@@ -459,6 +464,7 @@ fn crate_deps() {
     assert_eq!(outputs.content_by_mime_type, text_plain("765"));
 }
 
+#[cfg(not(windows))]
 #[test]
 fn crate_name_with_hyphens() {
     let (mut e, _) = new_command_context_and_outputs();
@@ -469,6 +475,7 @@ fn crate_name_with_hyphens() {
     assert_eq!(outputs.content_by_mime_type, text_plain("42"));
 }
 
+#[cfg(not(windows))]
 #[test]
 fn crate_show_deps() {
     let (mut e, _) = new_command_context_and_outputs();
@@ -557,7 +564,7 @@ fn continue_execution_after_bad_use_statement() {
             assert_eq!(errors.len(), 1);
             assert_eq!(errors[0].code(), Some("E0432"));
         }
-        x => panic!("Unexpected result: {:?}", x),
+        x => panic!("Unexpected result: {x:?}"),
     }
     // Now make sure we can still execute code.
     assert_eq!(eval!(e, "f".to_string() + "oo"), text_plain("\"foo\""));
@@ -585,7 +592,7 @@ fn error_from_macro_expansion() {
                 vec!["let mut s = String::new(); s.push_str(format!(\"\"));"]
             );
         }
-        x => panic!("Unexpected result: {:?}", x),
+        x => panic!("Unexpected result: {x:?}"),
     }
 }
 
@@ -650,7 +657,7 @@ fn abort_and_restart() {
             );
         }
     } else {
-        panic!("Unexpected result: {:?}", result);
+        panic!("Unexpected result: {result:?}");
     }
     eval!(e, assert_eq!(foo(), 42));
     assert!(e.defined_item_names().next().is_some());
@@ -703,10 +710,10 @@ fn unnamable_type_closure() {
     let result = e.execute(stringify!(let v = || {42};));
     if let Err(Error::Message(message)) = result {
         if !(message.starts_with("The variable") && message.contains("cannot be persisted")) {
-            panic!("Unexpected error: {:?}", message);
+            panic!("Unexpected error: {message:?}");
         }
     } else {
-        panic!("Unexpected result: {:?}", result);
+        panic!("Unexpected result: {result:?}");
     }
 }
 
@@ -723,10 +730,10 @@ fn unnamable_type_impl_trait() {
         if !(message.starts_with("The variable `v` has type")
             && message.contains("cannot be persisted"))
         {
-            panic!("Unexpected error: {:?}", message);
+            panic!("Unexpected error: {message:?}");
         }
     } else {
-        panic!("Unexpected result: {:?}", result);
+        panic!("Unexpected result: {result:?}");
     }
 }
 
