@@ -31,6 +31,6 @@ fn test_binary_execution() {
     let stderr = std::str::from_utf8(&output.stderr).unwrap();
     assert_eq!(stderr, "");
     if !stdout.contains("To install, run") {
-        panic!("Unexpected output:\n{:?}", stdout);
+        panic!("Unexpected output:\n{stdout:?}");
     }
 }
