@@ -9,7 +9,6 @@ use anyhow::Result;
 use ariadne::sources;
 use clap::Parser;
 use clap::ValueEnum;
-use colored::*;
 use evcxr::CommandContext;
 use evcxr::CompilationError;
 use evcxr::Error;
@@ -30,6 +29,8 @@ use rustyline::history::DefaultHistory;
 use std::fs;
 use std::io;
 use std::sync::Arc;
+use yansi::Color;
+use yansi::Paint as _;
 
 const PROMPT: &str = ">> ";
 
@@ -47,7 +48,7 @@ fn send_output<T: io::Write + Send + 'static>(
     std::thread::spawn(move || {
         while let Ok(line) = channel.recv() {
             let to_print = if let Some(color) = color {
-                format!("{}\n", line.color(color))
+                format!("{}\n", line.paint(color))
             } else {
                 format!("{line}\n")
             };
@@ -130,10 +131,6 @@ impl Repl {
     }
 
     fn display_errors(&mut self, source: &str, errors: Vec<CompilationError>) {
-        use yansi::Paint;
-        if cfg!(windows) && !Paint::enable_windows_ascii() {
-            Paint::disable()
-        }
         let mut last_span_lines: &Vec<String> = &vec![];
         for error in &errors {
             if error.is_from_user_code() {
@@ -270,9 +267,6 @@ fn main() -> Result<()> {
 
     let options = Options::parse();
 
-    #[cfg(windows)]
-    colored::control::set_virtual_terminal(true).ok();
-
     println!("Welcome to evcxr. For help, type :help");
     // Print this now, because we silence `:load_config` (writing to stdout
     // interferes with rustyline somewhat).
